@@ -12,9 +12,9 @@ sudo cpanm Pepper
 
 echo "Setting up Pepper - Please answer carefully"
 
-sudo pepper setup
+pepper setup
 
 echo "Starting Pepper"
 pepper start
 
-echo "Pepper now running at http://127.0.0.1:5000"
\ No newline at end of file
+echo "Pepper now running at http://127.0.0.1:5000"
